@@ -3,7 +3,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '1.07';
+$VERSION = '1.08';
 
 sub new {
     my $class = shift;
@@ -22,7 +22,7 @@ sub close {
 
 sub DESTROY {
     my $self = shift;
-    Lingua::LinkParser::dictionary_delete($self);
+    Lingua::LinkParser::dictionary_delete($self->{_dict});
 }
 
 1;
